==> paraview-5.12.0-6-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/StreamingParticles-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_depends" "ParaView::VTKExtensionsFiltersRendering;ParaView::RemotingViews;VTK::CommonCore;VTK::CommonDataModel;VTK::CommonExecutionModel")
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::FiltersCore;VTK::ParallelCore;VTK::RenderingCore;VTK::RenderingOpenGL2")
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_library_name" "vtkStreamingParticles")
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_forward_link" "VTK::PythonUsed")
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkPVRandomPointsStreamingSource.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkStreamingParticlesPriorityQueue.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkStreamingParticlesRepresentation.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkStreamingParticlesModule.h")
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/StreamingParticles/vtk/hierarchy/StreamingParticles/vtkStreamingParticles-hierarchy.txt")
unset(_vtk_module_import_prefix)

==> paraview-5.13.1-7-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/StreamingParticles-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_include_marshal" "FALSE")
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_depends" "ParaView::VTKExtensionsFiltersRendering;ParaView::RemotingViews;VTK::CommonCore;VTK::CommonDataModel;VTK::CommonExecutionModel")
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::FiltersCore;VTK::ParallelCore;VTK::RenderingCore;VTK::RenderingOpenGL2")
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_library_name" "vtkStreamingParticles")
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_forward_link" "VTK::PythonUsed")
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkPVRandomPointsStreamingSource.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkStreamingParticlesPriorityQueue.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkStreamingParticlesRepresentation.h")
set_property(TARGET "StreamingParticles::vtkStreamingParticles" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/StreamingParticles/vtk/hierarchy/StreamingParticles/vtkStreamingParticles-hierarchy.txt")
unset(_vtk_module_import_prefix)
